@@ -18,8 +18,8 @@ class RoomBase(abc.ABC):
 
         for key, val in cls.__dict__.items():
             if not key.startswith('__') and \
-                    callable(val) and hasattr(val, '_event'):
-                cls._event_handlers[val._event] = val  # type: ignore
+                    callable(val) and hasattr(val, '_ti_event_'):
+                cls._event_handlers[getattr(val, '_ti_event_')] = val
 
     def __init__(
             self,
@@ -233,8 +233,8 @@ class RoomBase(abc.ABC):
             # join is (again) finished
             return asyncio.create_task(self.on_join())
         else:
-            # User has decided not to wait for the join. Thus we can asume that
-            # event handlers do not depend on the on_join to be finished
+            # User has decided not to wait for the join. Thus we can assume
+            # that event handlers do not depend on the on_join to be finished
             assert self._wait_join is False
             assert self._client
             loop = self._client.get_event_loop()
@@ -268,7 +268,7 @@ class RoomBase(abc.ABC):
     @staticmethod
     def event(event: str) -> Callable[[Callable[P, R]], Callable[P, R]]:
         def wrapped(fun: Callable[P, R]) -> Callable[P, R]:
-            setattr(fun, '_event', event)
+            setattr(fun, '_ti_event_', event)
             return fun
 
         return wrapped
